@@ -5,6 +5,7 @@ import numba as nb
 import numpy as np
 from numba.experimental.jitclass.base import JitClassType
 from numba.experimental import jitclass
+from numpy.typing import NDArray
 from typing import Optional
 from abc import ABC
 
@@ -116,6 +117,15 @@ class Interface:  # pragma no cover
         """
         pass
 
+    def init_solver(self, t: float, y: np.array) -> None:
+        """Function called at once beginning of solve (normal, or step) method.
+
+        :param t:
+        :param y:
+        :return:
+        """
+        pass
+
     def post_step(self, t: float, y: np.array) -> SolveEvent:
         """Function called every time step has converged, and there was no event step in between.
 
@@ -184,7 +194,7 @@ class Interface:  # pragma no cover
         """
         return y
 
-    def get_next_time_event(self, t) -> Optional[tuple[list[int], float]]:
+    def get_next_time_event(self, t) -> Optional[tuple[list[int] | NDArray[int], float]]:
         """
         Function that is called after each converged solver step. Returns a tuple which contains an index of the next
         time event action function to be trigged, and the value of the time-step when the function is triggered.
@@ -193,7 +203,7 @@ class Interface:  # pragma no cover
         :type t: float
         :return: Optional: tuple of list of indexes of event function(s) and next time. If no function is triggered,
                  it should return None.
-        :rtype: Optional[tuple[list[int], float]]
+        :rtype: Optional[tuple[list[int] | NDArray[int], float]]
         """
         pass
 
