@@ -97,9 +97,6 @@ class NumerousSolver:
         else:
             self._solve = self._generate_solver()
 
-        self.interface.run_event_action(0, y0, -1)
-
-
     def _generate_solver(self):
         def _solve(interface, _solve_state, initial_step, dt_0, order, order_, roller, strict_eval,
                    min_step, max_step, step_integrate_, g, number_of_events, step_converged, event_trigger,
@@ -423,6 +420,7 @@ class NumerousSolver:
         order = self._method.order
 
         if not info:
+            self.interface.init_solver(time[0], self.y0)
             self.interface.pre_step(time[0], self.y0)
             solve_event_id = self.interface.historian_update(time[0], self.y0)
             self.event_handler.handle_solve_event(interface=self.interface, event_id=solve_event_id, t=time[0])
